/**
Check if the process is running inside a Docker container.

@example
```
import isDocker = require('is-docker');

if (isDocker()) {
	console.log('Running inside a Docker container');
}
```
*/
declare function isDocker(): boolean;

export = isDocker;
